################################################################################
Bolt Provided Tasks
################################################################################

Bolt provides the implementation of a few common tasks that most |python|_ 
projects should be able to leverage their functionality. This tasks are
registered when Bolt is executed, and users only need to configure and invoke
them in their ``boltfile.py``. 

The following documents the included tasks and how they work.

..  automodule:: bolt.tasks.bolt_delete_files 
    :members:


..  automodule:: bolt.tasks.bolt_mkdir
    :members:


..  automodule:: bolt.tasks.bolt_shell
    :members:



..  automodule:: bolt.tasks.bolt_pip
    :members:


..  automodule:: bolt.tasks.bolt_set_vars
    :members:


..  automodule:: bolt.tasks.bolt_setup
    :members:


..  automodule:: bolt.tasks.bolt_nose
    :members:

    
..  automodule:: bolt.tasks.bolt_conttest
    :members:
